@@ -29,6 +29,7 @@ public:
     ExtractorResult result;
     QVariant location;
     QJSEngine *m_jsEngine = nullptr;
+    QString usedExtractor;
 
     QJSEngine *jsEngine() const;
 };
@@ -232,4 +233,14 @@ QVariantList ExtractorDocumentNode::findChildNodes(const QJSValue &jsFilter) con
     return l;
 }
 
+QString ExtractorDocumentNode::usedExtractor() const
+{
+    return d->usedExtractor;
+}
+
+void ExtractorDocumentNode::setUsedExtractor(const QString &usedExtractor)
+{
+    d->usedExtractor = usedExtractor;
+}
+
 #include "moc_extractordocumentnode.cpp"
