@@ -32,10 +32,8 @@ namespace IataBcbpParser
  *  @param externalIssueDate The date the boarding pass was issued (or a sufficiently close approximation).
  *  This is necessary as by default the BCBP data only contains day and month of the flight, not the year.
  */
-QList<QVariant> parse(const QString &message,
-                      const QDateTime &externalIssueDateTime = QDateTime());
-KITINERARY_EXPORT QList<QVariant> parse(const IataBcbp &bcbp,
-                                        const QDateTime &contextDate);
+[[nodiscard]] QList<QVariant> parse(const QString &message, const QDateTime &externalIssueDateTime = QDateTime());
+[[nodiscard]] KITINERARY_EXPORT QList<QVariant> parse(const IataBcbp &bcbp, const QDateTime &contextDate);
 }
 
 }
