@@ -75,6 +75,11 @@ KITINERARY_EXPORT TrainStation stationForIataCode(IataCode iataCode);
 /** Lookup train station data by Amtrak station code. */
 KITINERARY_EXPORT TrainStation stationForAmtrakStationCode(AmtrakStationCode code);
 
+/** Lookup train station data by Via Rail station code. */
+KITINERARY_EXPORT TrainStation stationForViaRailStationCode(ViaRailStationCode code);
+
+/** Lookup train station data by UK railway station code. */
+KITINERARY_EXPORT TrainStation stationForUkRailwayStationCode(UKRailwayStationCode code);
 }
 }
 
