@@ -2,12 +2,14 @@
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 function parseDate(res, date) {
-    if (dt = date.match(/(\S+ \d{1,2})\S{2}, (\d{4})/)) {
-        res.reservationFor.startDate = JsonLd.toDateTime(dt[1] + dt[2], "MMMM ddyyyy", "en");
-    } else if (dt = date.match(/(\S+) (\d{1,2})\S{2}\S(\d{1,2})\S{2}, (\d{4})/)) {
-        console.log(dt);
+    if (dt = date.match(/(\S+) (\d{1,2})\S{2}\S(\d{1,2})\S{2}, (\d{4})/)) {
         res.reservationFor.startDate = JsonLd.toDateTime(dt[1] + ' ' + dt[2] + ' ' + dt[4], "MMMM d yyyy", "en");
         res.reservationFor.endDate = JsonLd.toDateTime(dt[1] + ' ' + dt[3] + ' ' + dt[4], "MMMM d yyyy", "en");
+    } else if (dt = date.match(/(\S+) (\d{1,2})\S{2}\S(\S+) (\d{1,2})\S{2}, (\d{4})/)) {
+        res.reservationFor.startDate = JsonLd.toDateTime(dt[1] + ' ' + dt[2] + ' ' + dt[5], "MMMM d yyyy", "en");
+        res.reservationFor.endDate = JsonLd.toDateTime(dt[3] + ' ' + dt[4] + ' ' + dt[5], "MMMM d yyyy", "en");
+    } else if (dt = date.match(/(\S+ \d{1,2})\S{2}, (\d{4})/)) {
+        res.reservationFor.startDate = JsonLd.toDateTime(dt[1] + dt[2], "MMMM ddyyyy", "en");
     }
 }
 
@@ -38,16 +40,17 @@ function extractPass(pass, node) {
 function extractPdf(pdf, node, barcode) {
     const page = pdf.pages[barcode.location];
     const topRight = page.textInRect(0.5, 0.0, 1.0, 0.5);
-    const ev = topRight.match(/([\S\s]+)\n(.*, \d{4})\n(?:\s*\d{1,2}:\d{2}[ap]m.*\n)?([\S\s]+)/);
+    const ev = topRight.match(/([\S\s]+)\n(.*,(?: |\n *)\d{4})\n(?:\s*\d{1,2}:\d{2}[ap]m.*\n)?([\S\s]+)/);
 
     let res = JsonLd.newEventReservation();
     res.reservationFor.name = ev[1];
-    parseDate(res, ev[2]);
     res.reservationFor.location.name = ev[3].match(/(.*)(?:By the power of)?/)[1];
     res.reservedTicket.ticketToken = 'qrCode:' + barcode.content;
 
     const left = page.textInRect(0.0, 0.0, 0.5, 1.0);
-    res.underName.name = left.match(/TICKET HOLDER\n(.*)\n/)[1];
+    const dt = left.match(/(.*, \d{4})\nTICKET HOLDER\n(.*)\n/);
+    parseDate(res, dt[1]);
+    res.underName.name = dt[2];
     res.reservationNumber = left.match(/REFERENCE\n(.*)\n/)[1];
     res.reservedTicket.name = left.match(/TICKET\n(.*)\n/)[1];
     const org = left.match(/EVENT HOMEPAGE\n *([\S\s]+)\n.*EMAIL\n *(\S.*)\n/);
